pub unsafe fn color_format_get_size(cf: ColorFormat) -> Result<u8>Expand description
Safety
This function is unsafe because it may dereference raw pointers.
pub unsafe fn color_format_get_size(cf: ColorFormat) -> Result<u8>This function is unsafe because it may dereference raw pointers.